Parrot.Media.G711Chunker (Parrot Platform v0.0.1-alpha.3)
Chunks G.711 encoded audio into RTP-sized packets.
This module is a Membrane filter that takes G.711 encoded audio buffers and splits them into appropriately sized chunks for RTP transmission. For G.711 audio at 8kHz, each 20ms RTP packet contains 160 samples (160 bytes).
Example
# In your pipeline
child(:g711_chunker, %Parrot.Media.G711Chunker{
chunk_duration: 20 # milliseconds
})Options
:chunk_duration- Duration of each chunk in milliseconds (default: 20ms)
Element options
Passed via struct Parrot.Media.G711Chunker.t/0
chunk_durationpos_integer()Default value:
20
Chunk duration in milliseconds
Pads
:input
Accepted formats:
G711| Direction: | :input |
| Availability: | :always |
| Flow control: | :auto |
:output
Accepted formats:
G711| Direction: | :output |
| Availability: | :always |
| Flow control: | :auto |
Summary
Types
Struct containing options for Parrot.Media.G711Chunker
Types
@type t() :: %Parrot.Media.G711Chunker{chunk_duration: pos_integer()}
Struct containing options for Parrot.Media.G711Chunker
Functions
@spec options() :: keyword()
Returns description of options available for this module